@@ -985,6 +985,19 @@ CREATE TABLE IF NOT EXISTS sso_tokens (
     INDEX idx_api_key_id (api_key_id)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
 
+-- API tokens for temporary authentication (WebSocket connections, etc.)
+CREATE TABLE IF NOT EXISTS api_tokens (
+    id INT AUTO_INCREMENT PRIMARY KEY,
+    token VARCHAR(128) NOT NULL UNIQUE,
+    username VARCHAR(50) NOT NULL,
+    expires_at DATETIME NOT NULL,
+    ip_address VARCHAR(45) NOT NULL,
+    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
+    INDEX idx_token (token),
+    INDEX idx_username (username),
+    INDEX idx_expires (expires_at)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
+
 -- Add API permissions to existing client_allowances table
 ALTER TABLE client_allowances 
 ADD COLUMN IF NOT EXISTS api_enabled BOOLEAN DEFAULT FALSE AFTER max_email_accounts,
