@@ -4,7 +4,7 @@ header('Content-Type: application/json');
 // Check API permission
 check_api_permission('terminal');
 
-require_once('/docker/whp/web/configs/config.php');
+require_once('/docker/whp/web/libs/mysqlmgmt.php');
 
 $response = ['success' => false, 'error' => 'Unknown error'];
 
@@ -15,8 +15,13 @@ if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
 }
 
 try {
-    $db = new PDO("mysql:host=localhost;dbname=whp;charset=utf8mb4", MYSQL_USER, MYSQL_PASS);
-    $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
+    $MySQLMgmt = new mysqlmgmt();
+    $db = $MySQLMgmt->getMySQLConnection();
+    if (!$db) {
+        $response = ['success' => false, 'error' => 'Database connection failed'];
+        echo json_encode($response);
+        exit;
+    }
     
     // Generate a temporary auth token for WebSocket connection
     $token = bin2hex(random_bytes(32));
